@@ -2,7 +2,7 @@ use github_actions_models::common::Uses;
 
 use super::{Audit, AuditLoadError, AuditState, audit_meta};
 use crate::audit::AuditError;
-use crate::config::{Config, ForbiddenUsesConfig};
+use crate::config::{Config, ForbiddenUsesConfigInner};
 use crate::finding::{Confidence, Finding, Persona, Severity};
 use crate::models::{StepCommon, action::CompositeStep, workflow::Step};
 
@@ -11,7 +11,7 @@ pub(crate) struct ForbiddenUses;
 audit_meta!(ForbiddenUses, "forbidden-uses", "forbidden action used");
 
 impl ForbiddenUses {
-    fn use_denied(&self, uses: &Uses, config: &ForbiddenUsesConfig) -> bool {
+    fn use_denied(&self, uses: &Uses, config: &ForbiddenUsesConfigInner) -> bool {
         match uses {
             // Local uses are never denied.
             Uses::Local(_) => false,
@@ -23,10 +23,10 @@ impl ForbiddenUses {
                 false
             }
             Uses::Repository(uses) => match config {
-                ForbiddenUsesConfig::Allow { allow } => {
+                ForbiddenUsesConfigInner::Allow(allow) => {
                     !allow.iter().any(|pattern| pattern.matches(uses))
                 }
-                ForbiddenUsesConfig::Deny { deny } => {
+                ForbiddenUsesConfigInner::Deny(deny) => {
                     deny.iter().any(|pattern| pattern.matches(uses))
                 }
             },
