@@ -1,11 +1,11 @@
 //! Models and APIs for handling findings and their locations.
 
-use anyhow::{Result, anyhow};
+use anyhow::anyhow;
 use clap::ValueEnum;
 use serde::{Deserialize, Serialize};
 
 use self::location::{Location, SymbolicLocation};
-use crate::{InputKey, models::AsDocument, registry::input::Group};
+use crate::{InputKey, audit::AuditError, models::AsDocument, registry::input::Group};
 use yamlpatch::{self, Patch};
 
 pub(crate) mod location;
@@ -126,6 +126,8 @@ pub(crate) struct Finding<'doc> {
     /// and carries metadata about how an output layer might choose to
     /// present it.
     pub(crate) locations: Vec<Location<'doc>>,
+    /// A tip or recommendation associated with this finding.
+    pub(crate) tip: Option<String>,
     /// Whether this finding is ignored, either via inline comments or
     /// through a user's configuration.
     pub(crate) ignored: bool,
@@ -176,6 +178,7 @@ pub(crate) struct FindingBuilder<'doc> {
     persona: Persona,
     raw_locations: Vec<Location<'doc>>,
     locations: Vec<SymbolicLocation<'doc>>,
+    tip: Option<String>,
     fixes: Vec<Fix<'doc>>,
 }
 
@@ -190,6 +193,7 @@ impl<'doc> FindingBuilder<'doc> {
             persona: Default::default(),
             raw_locations: vec![],
             locations: vec![],
+            tip: None,
             fixes: vec![],
         }
     }
@@ -219,6 +223,11 @@ impl<'doc> FindingBuilder<'doc> {
         self
     }
 
+    pub(crate) fn tip(mut self, tip: impl Into<String>) -> Self {
+        self.tip = Some(tip.into());
+        self
+    }
+
     pub(crate) fn fix(mut self, fix: Fix<'doc>) -> Self {
         self.fixes.push(fix);
         self
@@ -227,18 +236,20 @@ impl<'doc> FindingBuilder<'doc> {
     pub(crate) fn build<'a>(
         self,
         document: &'a impl AsDocument<'a, 'doc>,
-    ) -> Result<Finding<'doc>> {
+    ) -> Result<Finding<'doc>, AuditError> {
         let mut locations = self
             .locations
             .iter()
             .map(|l| l.clone().concretize(document.as_document()))
-            .collect::<Result<Vec<_>>>()?;
+            .collect::<anyhow::Result<Vec<_>>>()
+            .map_err(|e| AuditError::new(self.ident, e))?;
 
         locations.extend(self.raw_locations);
 
         if !locations.iter().any(|l| l.symbolic.is_primary()) {
-            return Err(anyhow!(
-                "API misuse: at least one location must be marked with primary()"
+            return Err(AuditError::new(
+                self.ident,
+                anyhow!("API misuse: at least one location must be marked with primary()"),
             ));
         }
 
@@ -254,6 +265,7 @@ impl<'doc> FindingBuilder<'doc> {
                 persona: self.persona,
             },
             locations,
+            tip: self.tip,
             ignored: should_ignore,
             fixes: self.fixes,
         })
